Changelog
=========

1.2.7 (2021-01-06)
------------------

- Fixed backend problem (wrong permission on vps folder)
- Back to 1.2.4


1.2.6 (2021-01-06)
------------------

- library.json.gz


1.2.5 (2021-01-06)
------------------

- Send library.json.gz


1.2.4 (2021-01-06)
------------------

- Écriture de la page grosses créatures
- Suppression d'une fonction en doublon dans le backend


1.2.3 (2021-01-04)
------------------

- Ajout robots.txt
- Ajout sitemap.xml
- Ajout d'une méthode pour les servir directement


1.2.2 (2021-01-04)
------------------

- Ajout d'un paragraphe sur les enchants à mana dans ramp
- Ajout d'un paragraphe sur les enchants à mana dans dorks
- Retrait du tip dans l'analyse de Kess
- Ajout d'une balise `<meta name="robots" content="all">` pour le data crawling


1.2.1 (2021-01-04)
------------------

- Corrections de l'outil analytique


1.2.0 (2021-01-04)
------------------

- Ajout outil analytique


1.1.1 (2021-01-04)
------------------

- Espacement entre paragraphes
- Correction de la page "ramp"


1.1.0 (2021-01-04)
------------------

- Correction des couleurs des decklists "light"
- Correction de l'espacement des cartes thématiques
- Changement de l'entrée "la recherche de créatures" par "les mana dorks"
- Rédaction de la page de ramp
- Rédaction de la page de mana dork


1.0.1 (2021-01-03)
------------------

- Fix og_description


1.0.0 (2021-01-03)
------------------

- Site en beta
